@@ -557,7 +557,7 @@ class ProtectionGroupsController(BaseController):
                                   cloud_spin_run_status=None,
                                   num_runs=None,
                                   exclude_non_restorable_runs=False,
-                                  run_tags=False):
+                                  run_tags=None):
         """Does a GET request to /data-protect/protection-groups/{id}/runs.
 
         Get the runs for a particular Protection Group.
