@@ -2,6 +2,7 @@ __all__ = [
     'a_w_s_fleet_params',
     'aag_and_databases',
     'aag_preference_enum',
+    'abort_incomplete_multipart_upload_action',
     'access_enum',
     'access_info_list_enum',
     'access_token',
@@ -121,6 +122,7 @@ __all__ = [
     'athena_slower_io_preferential_tier_enum',
     'attribute_restore_information',
     'attribute_value',
+    'audit_log_settings',
     'audit_logs_tile',
     'auth_method_enum',
     'auth_type_enum',
@@ -203,6 +205,7 @@ __all__ = [
     'cassandra_cluster',
     'cassandra_connect_params',
     'cassandra_keyspace',
+    'cassandra_log_recover_job_params',
     'cassandra_ports_info',
     'cassandra_protection_source',
     'cassandra_recover_job_params',
@@ -555,6 +558,7 @@ __all__ = [
     'get_all_job_runs_result',
     'get_consumer_stats_result',
     'get_job_run_info_result',
+    'get_linux_support_user_2fa_result',
     'get_map_reduce_app_runs_params',
     'get_mr_jar_upload_path_result',
     'get_objects_details_result',
@@ -645,6 +649,7 @@ __all__ = [
     'install_state_enum',
     'interface',
     'interface_group',
+    'interface_stats',
     'interval_enum',
     'interval_unit_enum',
     'io_preferential_tier',
@@ -706,6 +711,10 @@ __all__ = [
     'license_types_enum',
     'licensed_usage',
     'lifecycle_config_proto',
+    'lifecycle_rule',
+    'lifecycle_rule_filter',
+    'lifecycle_rule_filter_and',
+    'lifecycle_rule_filter_tag',
     'links',
     'linux_support_user_bash_shell_access_req_params',
     'linux_support_user_bash_shell_access_result',
@@ -742,6 +751,7 @@ __all__ = [
     'metric_data_point',
     'metric_enum',
     'metric_value',
+    'mfa_info',
     'migrate_oracle_clone_params',
     'mo_ref',
     'mode_enum',
@@ -828,6 +838,7 @@ __all__ = [
     'node_status_result',
     'node_system_disk_info',
     'node_to_tiered_storage_directories_map',
+    'noncurrent_version_expiration_action',
     'notification_rule',
     'notifications',
     'ntp_settings_config',
@@ -894,6 +905,7 @@ __all__ = [
     'org_vdc_network',
     'origin_enum',
     'os_disk_type_enum',
+    'otp_type_enum',
     'outlook_backup_env_params',
     'outlook_env_job_parameters',
     'outlook_folder',
@@ -935,6 +947,47 @@ __all__ = [
     'physical_type_enum',
     'physical_volume',
     'pkg_type_enum',
+    'pod_info_pod_spec_volume_info',
+    'pod_info_pod_spec_volume_info_aws_ebs',
+    'pod_info_pod_spec_volume_info_azure_disk',
+    'pod_info_pod_spec_volume_info_azure_file',
+    'pod_info_pod_spec_volume_info_cephfs',
+    'pod_info_pod_spec_volume_info_cinder',
+    'pod_info_pod_spec_volume_info_config_map',
+    'pod_info_pod_spec_volume_info_csi',
+    'pod_info_pod_spec_volume_info_csi_volume_attributes_entry',
+    'pod_info_pod_spec_volume_info_downward_api',
+    'pod_info_pod_spec_volume_info_downward_api_volume_file',
+    'pod_info_pod_spec_volume_info_downward_api_volume_file_object_field_selector',
+    'pod_info_pod_spec_volume_info_downward_api_volume_file_resource_field_selector',
+    'pod_info_pod_spec_volume_info_empty_dir',
+    'pod_info_pod_spec_volume_info_ephemeral_volume_source',
+    'pod_info_pod_spec_volume_info_fc',
+    'pod_info_pod_spec_volume_info_flex',
+    'pod_info_pod_spec_volume_info_flex_options_entry',
+    'pod_info_pod_spec_volume_info_flocker',
+    'pod_info_pod_spec_volume_info_gce_persistent_disk',
+    'pod_info_pod_spec_volume_info_gluster_fs',
+    'pod_info_pod_spec_volume_info_host_path',
+    'pod_info_pod_spec_volume_info_iscsi',
+    'pod_info_pod_spec_volume_info_key_to_path',
+    'pod_info_pod_spec_volume_info_local',
+    'pod_info_pod_spec_volume_info_nfs',
+    'pod_info_pod_spec_volume_info_photon_persistent_disk',
+    'pod_info_pod_spec_volume_info_portworx',
+    'pod_info_pod_spec_volume_info_projected',
+    'pod_info_pod_spec_volume_info_projected_volume_projection',
+    'pod_info_pod_spec_volume_info_projected_volume_projection_config_map_projection',
+    'pod_info_pod_spec_volume_info_projected_volume_projection_downward_api_projection',
+    'pod_info_pod_spec_volume_info_projected_volume_projection_service_account_token_projection',
+    'pod_info_pod_spec_volume_info_pvc',
+    'pod_info_pod_spec_volume_info_quobyte',
+    'pod_info_pod_spec_volume_info_rbd',
+    'pod_info_pod_spec_volume_info_scale_io',
+    'pod_info_pod_spec_volume_info_storage_os',
+    'pod_info_pod_spec_volume_info_vsphere_virtual_disk',
+    'pod_metadata',
+    'pod_metadata_volume_info',
     'postgres_node_info',
     'power_state_config_proto',
     'preferences',
@@ -1238,6 +1291,7 @@ __all__ = [
     'service_process_entry',
     'service_service_state_result_enum',
     'service_state_result',
+    'session_user',
     'setup_restore_disk_task_info_proto',
     'severity_enum',
     'severity_notification_rule_enum',
@@ -1474,6 +1528,7 @@ __all__ = [
     'uda_recover_params',
     'uda_restore_object',
     'uda_restore_object_params',
+    'uda_s3_view_backup_properties',
     'uda_source_capabilities',
     'un_register_application_servers_parameters',
     'universal_id',
@@ -1570,6 +1625,7 @@ __all__ = [
     'vault_type_vault_provider_stats_info_enum',
     'vcd_storage_profile',
     'vcloud_director_info',
+    'verify_otp_code_params',
     'view',
     'view_alias',
     'view_alias_info',
@@ -1643,4 +1699,4 @@ __all__ = [
     'worm_retention_type_protection_policy_request_enum',
     'yoda_io_preferential_tier_enum',
     'zone_config'
-]
+]
\ No newline at end of file
