@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 import cohesity_management_sdk.models.a_w_s_fleet_params
+import cohesity_management_sdk.models.c2s_server_info
 import cohesity_management_sdk.models.fleet_network_params
 import cohesity_management_sdk.models.tag_attribute
+import cohesity_management_sdk.models.ebs_volume_info
 
 class AwsProtectionSource(object):
 
@@ -42,7 +44,10 @@ class AwsProtectionSource(object):
             configuring database features. 'kRDSParameterGroup' represents a
             RDS parameter group. 'kRDSInstance' represents a RDS DB instance.
             'kRDSSubnet' represents a RDS subnet. 'kRDSTag' represents a tag
-            attached to RDS instance.
+            attached to RDS instance. 'kAuroraCluster' represents an Aurora
+            cluster.
+        c2s_server_info (C2SServerInfo): Specifies the C2S Access Portal (CAP)
+            server info.
         cluster_network_info (FleetNetworkParams): Specifies information
             related to cluster. This is only valid for CE clusters. This is
             only populated for kIAMUser entity.
@@ -119,11 +124,13 @@ class AwsProtectionSource(object):
             'kRDSParameterGroup' represents a RDS parameter group.
             'kRDSInstance' represents a RDS DB instance. 'kRDSSubnet'
             represents a RDS subnet. 'kRDSTag' represents a tag attached to
-            RDS instance.
+            RDS instance. 'kAuroraCluster' represents an Aurora cluster.
         user_account_id (string): Specifies the account id derived from the
             ARN of the user.
         user_resource_name (string): Specifies the Amazon Resource Name (ARN)
             of the user.
+        volumes (list of EbsVolumeInfo): Specified the list of EBS volumes
+            attached to the entity if the entity is an EC2 instance.
 
     """
 
@@ -134,6 +141,7 @@ class AwsProtectionSource(object):
         "auth_method":'authMethod',
         "aws_fleet_params":'awsFleetParams',
         "aws_type":'awsType',
+        "c2s_server_info":'c2sServerInfo',
         "cluster_network_info":'clusterNetworkInfo',
         "db_engine_id":'dbEngineId',
         "host_type":'hostType',
@@ -150,7 +158,8 @@ class AwsProtectionSource(object):
         "tag_attributes":'tagAttributes',
         "mtype":'type',
         "user_account_id":'userAccountId',
-        "user_resource_name":'userResourceName'
+        "user_resource_name":'userResourceName',
+        "volumes":'volumes'
     }
 
     def __init__(self,
@@ -159,6 +168,7 @@ class AwsProtectionSource(object):
                  auth_method=None,
                  aws_fleet_params=None,
                  aws_type=None,
+                 c2s_server_info=None,
                  cluster_network_info=None,
                  db_engine_id=None,
                  host_type=None,
@@ -175,7 +185,8 @@ class AwsProtectionSource(object):
                  tag_attributes=None,
                  mtype=None,
                  user_account_id=None,
-                 user_resource_name=None):
+                 user_resource_name=None,
+                 volumes=None):
         """Constructor for the AwsProtectionSource class"""
 
         # Initialize members of the class
@@ -184,6 +195,7 @@ class AwsProtectionSource(object):
         self.auth_method = auth_method
         self.aws_fleet_params = aws_fleet_params
         self.aws_type = aws_type
+        self.c2s_server_info = c2s_server_info
         self.cluster_network_info = cluster_network_info
         self.db_engine_id = db_engine_id
         self.host_type = host_type
@@ -201,6 +213,7 @@ class AwsProtectionSource(object):
         self.mtype = mtype
         self.user_account_id = user_account_id
         self.user_resource_name = user_resource_name
+        self.volumes = volumes
 
 
     @classmethod
@@ -226,6 +239,7 @@ class AwsProtectionSource(object):
         auth_method = dictionary.get('authMethod')
         aws_fleet_params = cohesity_management_sdk.models.a_w_s_fleet_params.AwsFleetParams.from_dictionary(dictionary.get('awsFleetParams')) if dictionary.get('awsFleetParams') else None
         aws_type = dictionary.get('awsType')
+        c2s_server_info = cohesity_management_sdk.models.c2s_server_info.C2SServerInfo.from_dictionary(dictionary.get('c2sServerInfo')) if dictionary.get('c2sServerInfo') else None
         cluster_network_info = cohesity_management_sdk.models.fleet_network_params.FleetNetworkParams.from_dictionary(dictionary.get('clusterNetworkInfo')) if dictionary.get('clusterNetworkInfo') else None
         db_engine_id = dictionary.get('dbEngineId')
         host_type = dictionary.get('hostType')
@@ -247,6 +261,11 @@ class AwsProtectionSource(object):
         mtype = dictionary.get('type')
         user_account_id = dictionary.get('userAccountId')
         user_resource_name = dictionary.get('userResourceName')
+        volumes = None
+        if dictionary.get('volumes') != None:
+            volumes = list()
+            for structure in dictionary.get('volumes'):
+                volumes.append(cohesity_management_sdk.models.ebs_volume_info.EbsVolumeInfo.from_dictionary(structure))
 
         # Return an object of this model
         return cls(access_key,
@@ -254,6 +273,7 @@ class AwsProtectionSource(object):
                    auth_method,
                    aws_fleet_params,
                    aws_type,
+                   c2s_server_info,
                    cluster_network_info,
                    db_engine_id,
                    host_type,
@@ -270,6 +290,7 @@ class AwsProtectionSource(object):
                    tag_attributes,
                    mtype,
                    user_account_id,
-                   user_resource_name)
+                   user_resource_name,
+                   volumes)
 
 
