@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 import cohesity_management_sdk.models.alerting_policy_proto
 import cohesity_management_sdk.models.backup_source_params
@@ -18,6 +18,7 @@ import cohesity_management_sdk.models.source_filters
 import cohesity_management_sdk.models.stubbing_policy_proto
 import cohesity_management_sdk.models.standby_resource
 import cohesity_management_sdk.models.user_information
+import cohesity_management_sdk.models.backup_job_proto_remote_view_params
 import cohesity_management_sdk.models.physical_file_backup_params_global_include_exclude
 
 class BackupJobProto(object):
@@ -97,6 +98,14 @@ class BackupJobProto(object):
         is_active (bool): Whether the backup job is active or not. Details
             about what an active job is can be found here:
             https://goo.gl/1mLvS3.
+        is_cdp_sync_replication_enabled (bool): If set to true and backup job policy
+            has CDP parameters as well as snapshot replication target policy is
+            specified then data is synchronously replicated to the replication
+            target through Atom service.
+        is_cloud_archive_direct (bool): Denotes whether the backup job is
+            CloudArchiveDirect (excluding NAS direct archive in native format).
+            NAS direct archive jobs in native format can be
+            identified by checking for the 'is_direct_archive_enabled' field.
         is_continuous_snapshotting_enabled (bool): Indicates if Magneto should
             continue taking source snapshots even if there is a pending run.
         is_deleted (bool): Tracks whether the backup job has actually been
@@ -111,6 +120,8 @@ class BackupJobProto(object):
         is_direct_archive_native_format_enabled (bool): This field is set to
             true if native format should be used for archiving. Applicable for
             only direct archive jobs.
+        is_internal (bool): Whether the backup job is an internal job. These
+            jobs are hidden from the user, and are created internally.
         is_paused (bool): Whether the backup job is paused. New backup runs
             are not scheduled for the paused backup job. Active run of a
             backup job (if any) is not impacted.
@@ -140,6 +151,12 @@ class BackupJobProto(object):
             applicable.
         last_updated_username (string): The user who modified the job most
             recently.
+        leverage_nutanix_snapshots (bool): This is set to true by the user if
+            nutanix snapshot is requested
+            This is applicable in case if the vcenter in question is registered
+            as a management server on a prism endpoint. This flag will be
+            ignored at the backend if it is not feasible to leverage nutanix
+            snapshot.
         leverage_san_transport (bool): This is set to true by the user in
             order to backup the objects via a dedicated storage area network
             (SAN), as opposed to transport via LAN or management network.
@@ -166,6 +183,9 @@ class BackupJobProto(object):
             environment. If not specified, then snapshots will not be be
             deleted from the primary environment. NOTE: This is only
             applicable for certain environments like kPure.
+        object_backup_spec_uid (UniversalIdProto): The universal Id of the
+            ObjectBackupSpecification which is used by this backup job.This is
+            relavent only for internal jobs.
         parent_source (EntityProto): The registered source managing all the
             sources being backed up. This field is optional.
         perform_source_side_dedup (bool): Whether or not to perform source
@@ -219,6 +239,7 @@ class BackupJobProto(object):
             protection group, 'remoteViewParams' is the new field which captures
             this information for view backups, 'remote_view_name' here is now only
             used for Remote Adapter jobs (kPuppeteer).
+        remote_view_params (BackupJobProto_RemoteViewParams): TODO:
         required_feature_vec (list of string): The features that are strictly
             required to be supported by the cluster of the backup job. This is
             currently used in the following cases: 1. Tx cluster looks at the
@@ -302,10 +323,13 @@ class BackupJobProto(object):
         "global_include_exclude":'globalIncludeExclude',
         "indexing_policy":'indexingPolicy',
         "is_active":'isActive',
+        "is_cdp_sync_replication_enabled":'isCdpSyncReplicationEnabled',
+        "is_cloud_archive_direct":'isCloudArchiveDirect',
         "is_continuous_snapshotting_enabled":'isContinuousSnapshottingEnabled',
         "is_deleted":'isDeleted',
         "is_direct_archive_enabled":'isDirectArchiveEnabled',
         "is_direct_archive_native_format_enabled":'isDirectArchiveNativeFormatEnabled',
+        "is_internal":'isInternal',
         "is_paused":'isPaused',
         "is_rpo_job":'isRpoJob',
         "job_creation_time_usecs":'jobCreationTimeUsecs',
@@ -316,6 +340,7 @@ class BackupJobProto(object):
         "last_pause_modification_time_usecs":'lastPauseModificationTimeUsecs',
         "last_pause_reason":'lastPauseReason',
         "last_updated_username":'lastUpdatedUsername',
+        "leverage_nutanix_snapshots": 'leverageNutanixSnapshots',
         "leverage_san_transport":'leverageSanTransport',
         "leverage_storage_snapshots":'leverageStorageSnapshots',
         "leverage_storage_snapshots_for_hyperflex":'leverageStorageSnapshotsForHyperflex',
@@ -323,6 +348,7 @@ class BackupJobProto(object):
         "max_allowed_source_snapshots":'maxAllowedSourceSnapshots',
         "name":'name',
         "num_snapshots_to_keep_on_primary":'numSnapshotsToKeepOnPrimary',
+        "object_backup_spec_uid":'objectBackupSpecUid',
         "parent_source":'parentSource',
         "perform_source_side_dedup":'performSourceSideDedup',
         "policy_applied_time_msecs":'policyAppliedTimeMsecs',
@@ -335,12 +361,13 @@ class BackupJobProto(object):
         "quiesce":'quiesce',
         "remote_job_uids":'remoteJobUids',
         "remote_view_name":'remoteViewName',
+        "remote_view_params":'remoteViewParams',
         "required_feature_vec":'requiredFeatureVec',
         "skip_tenant_validations":'skipTenantValidations',
         "sla_time_mins":'slaTimeMins',
         "source_filters":'sourceFilters',
         "sources":'sources',
-        "standby_resource_vec":'standby_resource_vec',
+        "standby_resource_vec":'standbyResourceVec',
         "start_time":'startTime',
         "stubbing_policy":'stubbingPolicy',
         "tag_vec":'tagVec',
@@ -374,10 +401,13 @@ class BackupJobProto(object):
                  global_include_exclude=None,
                  indexing_policy=None,
                  is_active=None,
+                 is_cdp_sync_replication_enabled=None,
+                 is_cloud_archive_direct=None,
                  is_continuous_snapshotting_enabled=None,
                  is_deleted=None,
                  is_direct_archive_enabled=None,
                  is_direct_archive_native_format_enabled=None,
+                 is_internal=None,
                  is_paused=None,
                  is_rpo_job=None,
                  job_creation_time_usecs=None,
@@ -388,6 +418,7 @@ class BackupJobProto(object):
                  last_pause_modification_time_usecs=None,
                  last_pause_reason=None,
                  last_updated_username=None,
+                 leverage_nutanix_snapshots=None,
                  leverage_san_transport=None,
                  leverage_storage_snapshots=None,
                  leverage_storage_snapshots_for_hyperflex=None,
@@ -395,6 +426,7 @@ class BackupJobProto(object):
                  max_allowed_source_snapshots=None,
                  name=None,
                  num_snapshots_to_keep_on_primary=None,
+                 object_backup_spec_uid=None,
                  parent_source=None,
                  perform_source_side_dedup=None,
                  policy_applied_time_msecs=None,
@@ -407,6 +439,7 @@ class BackupJobProto(object):
                  quiesce=None,
                  remote_job_uids=None,
                  remote_view_name=None,
+                 remote_view_params=None,
                  required_feature_vec=None,
                  skip_tenant_validations=None,
                  sla_time_mins=None,
@@ -446,10 +479,13 @@ class BackupJobProto(object):
         self.global_include_exclude = global_include_exclude
         self.indexing_policy = indexing_policy
         self.is_active = is_active
+        self.is_cdp_sync_replication_enabled = is_cdp_sync_replication_enabled
+        self.is_cloud_archive_direct = is_cloud_archive_direct
         self.is_continuous_snapshotting_enabled = is_continuous_snapshotting_enabled
         self.is_deleted = is_deleted
         self.is_direct_archive_enabled = is_direct_archive_enabled
         self.is_direct_archive_native_format_enabled = is_direct_archive_native_format_enabled
+        self.is_internal = is_internal
         self.is_paused = is_paused
         self.is_rpo_job = is_rpo_job
         self.job_creation_time_usecs = job_creation_time_usecs
@@ -460,6 +496,7 @@ class BackupJobProto(object):
         self.last_pause_modification_time_usecs = last_pause_modification_time_usecs
         self.last_pause_reason = last_pause_reason
         self.last_updated_username = last_updated_username
+        self.leverage_nutanix_snapshots = leverage_nutanix_snapshots
         self.leverage_san_transport = leverage_san_transport
         self.leverage_storage_snapshots = leverage_storage_snapshots
         self.leverage_storage_snapshots_for_hyperflex = leverage_storage_snapshots_for_hyperflex
@@ -467,6 +504,7 @@ class BackupJobProto(object):
         self.max_allowed_source_snapshots = max_allowed_source_snapshots
         self.name = name
         self.num_snapshots_to_keep_on_primary = num_snapshots_to_keep_on_primary
+        self.object_backup_spec_uid = object_backup_spec_uid
         self.parent_source = parent_source
         self.perform_source_side_dedup = perform_source_side_dedup
         self.policy_applied_time_msecs = policy_applied_time_msecs
@@ -479,6 +517,7 @@ class BackupJobProto(object):
         self.quiesce = quiesce
         self.remote_job_uids = remote_job_uids
         self.remote_view_name = remote_view_name
+        self.remote_view_params = remote_view_params
         self.required_feature_vec = required_feature_vec
         self.skip_tenant_validations = skip_tenant_validations
         self.sla_time_mins = sla_time_mins
@@ -551,10 +590,13 @@ class BackupJobProto(object):
         global_include_exclude = cohesity_management_sdk.models.physical_file_backup_params_global_include_exclude.PhysicalFileBackupParams_GlobalIncludeExclude.from_dictionary(dictionary.get('globalIncludeExclude')) if dictionary.get('globalIncludeExclude') else None
         indexing_policy = cohesity_management_sdk.models.indexing_policy_proto.IndexingPolicyProto.from_dictionary(dictionary.get('indexingPolicy')) if dictionary.get('indexingPolicy') else None
         is_active = dictionary.get('isActive')
+        is_cdp_sync_replication_enabled = dictionary.get('isCdpSyncReplicationEnabled')
+        is_cloud_archive_direct = dictionary.get('isCloudArchiveDirect')
         is_continuous_snapshotting_enabled = dictionary.get('isContinuousSnapshottingEnabled')
         is_deleted = dictionary.get('isDeleted')
         is_direct_archive_enabled = dictionary.get('isDirectArchiveEnabled')
         is_direct_archive_native_format_enabled = dictionary.get('isDirectArchiveNativeFormatEnabled')
+        is_internal = dictionary.get('isInternal')
         is_paused = dictionary.get('isPaused')
         is_rpo_job = dictionary.get('isRpoJob')
         job_creation_time_usecs = dictionary.get('jobCreationTimeUsecs')
@@ -565,6 +607,7 @@ class BackupJobProto(object):
         last_pause_modification_time_usecs = dictionary.get('lastPauseModificationTimeUsecs')
         last_pause_reason = dictionary.get('lastPauseReason')
         last_updated_username = dictionary.get('lastUpdatedUsername')
+        leverage_nutanix_snapshots = dictionary.get('leverageNutanixSnapshots')
         leverage_san_transport = dictionary.get('leverageSanTransport')
         leverage_storage_snapshots = dictionary.get('leverageStorageSnapshots')
         leverage_storage_snapshots_for_hyperflex = dictionary.get('leverageStorageSnapshotsForHyperflex')
@@ -572,6 +615,7 @@ class BackupJobProto(object):
         max_allowed_source_snapshots = dictionary.get('maxAllowedSourceSnapshots')
         name = dictionary.get('name')
         num_snapshots_to_keep_on_primary = dictionary.get('numSnapshotsToKeepOnPrimary')
+        object_backup_spec_uid = cohesity_management_sdk.models.universal_id_proto.UniversalIdProto.from_dictionary(dictionary.get('objectBackupSpecUid')) if dictionary.get('objectBackupSpecUid') else None
         parent_source = cohesity_management_sdk.models.entity_proto.EntityProto.from_dictionary(dictionary.get('parentSource')) if dictionary.get('parentSource') else None
         perform_source_side_dedup = dictionary.get('performSourceSideDedup')
         policy_applied_time_msecs = dictionary.get('policyAppliedTimeMsecs')
@@ -588,6 +632,7 @@ class BackupJobProto(object):
             for structure in dictionary.get('remoteJobUids'):
                 remote_job_uids.append(cohesity_management_sdk.models.universal_id_proto.UniversalIdProto.from_dictionary(structure))
         remote_view_name = dictionary.get('remoteViewName')
+        remote_view_params = cohesity_management_sdk.models.backup_job_proto_remote_view_params.BackupJobProto_RemoteViewParams.from_dictionary(dictionary.get('remoteViewParams')) if dictionary.get('remoteViewParams') else None
         required_feature_vec = dictionary.get('requiredFeatureVec')
         skip_tenant_validations = dictionary.get('skipTenantValidations')
         sla_time_mins = dictionary.get('slaTimeMins')
@@ -598,9 +643,9 @@ class BackupJobProto(object):
             for structure in dictionary.get('sources'):
                 sources.append(cohesity_management_sdk.models.backup_job_proto_backup_source.BackupJobProtoBackupSource.from_dictionary(structure))
         standby_resource_vec = None
-        if dictionary.get('standby_resource_vec') != None:
+        if dictionary.get('standbyResourceVec') != None:
             standby_resource_vec = list()
-            for structure in dictionary.get('standby_resource_vec'):
+            for structure in dictionary.get('standbyResourceVec'):
                 standby_resource_vec.append(cohesity_management_sdk.models.standby_resource.StandbyResource.from_dictionary(structure))
         start_time = cohesity_management_sdk.models.time.Time.from_dictionary(dictionary.get('startTime')) if dictionary.get('startTime') else None
         stubbing_policy = cohesity_management_sdk.models.stubbing_policy_proto.StubbingPolicyProto.from_dictionary(dictionary.get('stubbingPolicy')) if dictionary.get('stubbingPolicy') else None
@@ -634,8 +679,13 @@ class BackupJobProto(object):
                    global_include_exclude,
                    indexing_policy,
                    is_active,
+                   is_cdp_sync_replication_enabled,
+                   is_cloud_archive_direct,
+                   is_continuous_snapshotting_enabled,
+                   is_deleted,
                    is_direct_archive_enabled,
                    is_direct_archive_native_format_enabled,
+                   is_internal,
                    is_paused,
                    is_rpo_job,
                    job_creation_time_usecs,
@@ -646,6 +696,7 @@ class BackupJobProto(object):
                    last_pause_modification_time_usecs,
                    last_pause_reason,
                    last_updated_username,
+                   leverage_nutanix_snapshots,
                    leverage_san_transport,
                    leverage_storage_snapshots,
                    leverage_storage_snapshots_for_hyperflex,
@@ -653,6 +704,7 @@ class BackupJobProto(object):
                    max_allowed_source_snapshots,
                    name,
                    num_snapshots_to_keep_on_primary,
+                   object_backup_spec_uid,
                    parent_source,
                    perform_source_side_dedup,
                    policy_applied_time_msecs,
@@ -665,6 +717,7 @@ class BackupJobProto(object):
                    quiesce,
                    remote_job_uids,
                    remote_view_name,
+                   remote_view_params,
                    required_feature_vec,
                    skip_tenant_validations,
                    sla_time_mins,
