@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 
 class ConnectorParameters(object):
@@ -10,6 +10,8 @@ class ConnectorParameters(object):
     a particular environment.
 
     Attributes:
+        connection_id (long|int): ID of the Bifrost (HyX or Rigel) network
+            realm (i.e. a connection) associated with the source.
         endpoint (string): Specify an IP address or URL of the environment.
             (such as the IP address of the vCenter Server for a VMware
             environment).
@@ -58,6 +60,7 @@ class ConnectorParameters(object):
             environment. 'kHdfs' indicates Hdfs Protection Source environment.
             'kHive' indicates Hive Protection Source environment. 'kHBase'
             indicates HBase Protection Source environment.
+            'kUDA' indicates Universal Data Adapter Protection Source environment.
         id (long|int): Specifies a Unique id that is generated when the Source
             is registered. This is a convenience field that is used to
             maintain an index to different connection params.
@@ -69,6 +72,7 @@ class ConnectorParameters(object):
 
     # Create a mapping from Model property names to API property names
     _names = {
+        "connection_id":'connectionId',
         "endpoint":'endpoint',
         "environment":'environment',
         "id":'id',
@@ -76,6 +80,7 @@ class ConnectorParameters(object):
     }
 
     def __init__(self,
+                 connection_id=None,
                  endpoint=None,
                  environment=None,
                  id=None,
@@ -83,6 +88,7 @@ class ConnectorParameters(object):
         """Constructor for the ConnectorParameters class"""
 
         # Initialize members of the class
+        self.connection_id = connection_id
         self.endpoint = endpoint
         self.environment = environment
         self.id = id
@@ -107,13 +113,15 @@ class ConnectorParameters(object):
             return None
 
         # Extract variables from the dictionary
+        connection_id = dictionary.get('connectionId')
         endpoint = dictionary.get('endpoint')
         environment = dictionary.get('environment')
         id = dictionary.get('id')
         version = dictionary.get('version')
 
         # Return an object of this model
-        return cls(endpoint,
+        return cls(connection_id,
+                   endpoint,
                    environment,
                    id,
                    version)
