@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 import cohesity_management_sdk.models.user_id_mapping
 import cohesity_management_sdk.models.preferred_domain_controller
@@ -15,6 +15,8 @@ class CreateActiveDirectoryEntryParams(object):
             of an Active Directory.
         fallback_user_id_mapping_info (UserIdMapping): Specifies how the Unix
             and Windows users are mapped in an Active Directory.
+        force_remove (bool): Specifies if Active Directory entry should be
+            force removed from cluster.
         ignored_trusted_domains (list of string): Specifies the list of
             trusted domains that were set by the user to be ignored during
             trusted domain discovery.
@@ -51,6 +53,7 @@ class CreateActiveDirectoryEntryParams(object):
     _names = {
         "domain_name":'domainName',
         "fallback_user_id_mapping_info":'fallbackUserIdMappingInfo',
+        "force_remove":'forceRemove',
         "ignored_trusted_domains":'ignoredTrustedDomains',
         "ldap_provider_id":'ldapProviderId',
         "machine_accounts":'machineAccounts',
@@ -71,6 +74,7 @@ class CreateActiveDirectoryEntryParams(object):
     def __init__(self,
                  domain_name=None,
                  fallback_user_id_mapping_info=None,
+                 force_remove=None,
                  ignored_trusted_domains=None,
                  ldap_provider_id=None,
                  machine_accounts=None,
@@ -91,6 +95,7 @@ class CreateActiveDirectoryEntryParams(object):
         # Initialize members of the class
         self.domain_name = domain_name
         self.fallback_user_id_mapping_info = fallback_user_id_mapping_info
+        self.force_remove = force_remove
         self.ignored_trusted_domains = ignored_trusted_domains
         self.ldap_provider_id = ldap_provider_id
         self.machine_accounts = machine_accounts
@@ -128,6 +133,7 @@ class CreateActiveDirectoryEntryParams(object):
         # Extract variables from the dictionary
         domain_name = dictionary.get('domainName')
         fallback_user_id_mapping_info = cohesity_management_sdk.models.user_id_mapping.UserIdMapping.from_dictionary(dictionary.get('fallbackUserIdMappingInfo')) if dictionary.get('fallbackUserIdMappingInfo') else None
+        force_remove = dictionary.get('forceRemove')
         ignored_trusted_domains = dictionary.get('ignoredTrustedDomains')
         ldap_provider_id = dictionary.get('ldapProviderId')
         machine_accounts = dictionary.get('machineAccounts')
@@ -151,6 +157,7 @@ class CreateActiveDirectoryEntryParams(object):
         # Return an object of this model
         return cls(domain_name,
                    fallback_user_id_mapping_info,
+                   force_remove,
                    ignored_trusted_domains,
                    ldap_provider_id,
                    machine_accounts,
