@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 class EnvironmentRegisterProtectionSourceParametersEnum(object):
 
@@ -95,6 +95,7 @@ class EnvironmentRegisterProtectionSourceParametersEnum(object):
         KHDFS: TODO: type description here.
         KHIVE: TODO: type description here.
         KHBASE: TODO: type description here.
+        KUDA: TODO: type description here.
 
 
     """
@@ -177,4 +178,6 @@ class EnvironmentRegisterProtectionSourceParametersEnum(object):
 
     KHBASE = 'kHBase'
 
+    KUDA = 'kUDA'
+
 
