@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 class JobTypeEnum(object):
 
@@ -91,6 +91,7 @@ class JobTypeEnum(object):
         KHDFS: TODO: type description here.
         KHIVE: TODO: type description here.
         KHBASE: TODO: type description here.
+        KUDA: TODO: type description here.
 
 
     """
@@ -172,5 +173,7 @@ class JobTypeEnum(object):
     KHIVE = 'kHive'
 
     KHBASE = 'kHBase'
+
+    KUDA = 'kUDA'
     
 
