@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 class ObjectClassIdpPrincipalsAddParametersEnum(object):
 
@@ -12,12 +12,14 @@ class ObjectClassIdpPrincipalsAddParametersEnum(object):
     'kGroup' specifies a group object class.
     'kComputer' specifies a computer object class.
     'kWellKnownPrincipal' specifies a well known principal.
+    'kServiceAccount' specifies a service account object class.
 
     Attributes:
         KUSER: TODO: type description here.
         KGROUP: TODO: type description here.
         KCOMPUTER: TODO: type description here.
         KWELLKNOWNPRINCIPAL: TODO: type description here.
+        KSERVICEACCOUNT: TODO: type description here.
 
     """
 
@@ -29,3 +31,4 @@ class ObjectClassIdpPrincipalsAddParametersEnum(object):
 
     KWELLKNOWNPRINCIPAL = 'kWellKnownPrincipal'
 
+    KSERVICEACCOUNT = 'kServiceAccount'
