@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 import cohesity_management_sdk.models.aws_credentials
 import cohesity_management_sdk.models.a_w_s_fleet_params
@@ -7,9 +7,11 @@ import cohesity_management_sdk.models.azure_credentials
 import cohesity_management_sdk.models.exchange_dag_protection_preference
 import cohesity_management_sdk.models.fleet_network_params
 import cohesity_management_sdk.models.gcp_credentials
+import cohesity_management_sdk.models.registered_protection_source_isilon_params
 import cohesity_management_sdk.models.kubernetes_credentials
 import cohesity_management_sdk.models.nas_mount_credential_params
 import cohesity_management_sdk.models.office_365_credentials
+import cohesity_management_sdk.models.physical_params
 import cohesity_management_sdk.models.ssl_verification
 import cohesity_management_sdk.models.subnet
 import cohesity_management_sdk.models.throttling_policy_parameters
@@ -28,6 +30,9 @@ class RegisterProtectionSourceParameters(object):
             environment is kAcropolis. overrideDescription: true
         agent_endpoint (string): Specifies the agent endpoint if it is
             different from the source endpoint.
+        allowed_ip_addresses (list of string): Specifies the list of IP
+            Addresses on the registered source to be exclusively allowed for
+            doing any type of IO operations.
         aws_credentials (AwsCredentials): Specifies the credentials to
             authenticate with AWS Cloud Platform.
         aws_fleet_params (AwsFleetParams): Specifies information related to
@@ -41,6 +46,16 @@ class RegisterProtectionSourceParameters(object):
         cluster_network_info (FleetNetworkParams): Specifies information
             related to cluster. This is only valid for CE clusters. This is
             only populated for kIAMUser entity.
+        connection_id (long|int): Specifies the Bifrost realm to be associated
+            with the source root. Whenever needed, the workflows related to
+            this source would then only use Bifrosts from the specified realm.
+        denied_ip_addresses (list of string): Specifies the list of IP
+            Addresses on the registered source to be denied for doing any
+            type of IO operations.
+        encryption_key (string): If set, user has encrypted the credential with
+            'user_ecryption_key'. It is assumed that credentials are first
+            encrypted using internal magento key and then encrypted using user
+            encryption key.
         endpoint (string): Specifies the network endpoint of the Protection
             Source where it is reachable. It could be an URL or hostname or an
             IP address of the Protection Source.
@@ -89,7 +104,8 @@ class RegisterProtectionSourceParameters(object):
             environment. 'kCouchbase' indicates Couchbase Protection Source
             environment. 'kHdfs' indicates Hdfs Protection Source environment.
             'kHive' indicates Hive Protection Source environment. 'kHBase'
-            indicates HBase Protection Source environment.
+            indicates HBase Protection Source environment. 'kUDA' indicates
+            Universal Data Adapter Protection Source environment.
         exchange_dag_protection_preference (ExchangeDAGProtectionPreference):
             Specifies information about the preference order while choosing
             between which database copy of the exchange database which is part
@@ -112,6 +128,12 @@ class RegisterProtectionSourceParameters(object):
             SE. 'kOther' indicates the other types of operating system.
         hyperv_type (HypervTypeEnum): Specifies the entity type if the
             environment is kHyperV. overrideDescription: true
+        is_internal_encrypted (bool): Set to true if credentials are encrypted
+            by internal magneto key.
+        is_proxy_host (bool): Specifies if the physical host has to be
+            registered as a proxy host.
+        isilon_params (RegisteredProtectionSourceIsilonParams): Specifies the
+            registered protection source params for Isilon Source
         kubernetes_credentials (KubernetesCredentials): Specifies the
             credentials to authenticate with a Kubernetes Cluster.
         kubernetes_type (KubernetesTypeEnum): Specifies the entity type if the
@@ -135,16 +157,17 @@ class RegisterProtectionSourceParameters(object):
             'kDomain', 'kOutlook', 'kMailbox', if the environment is kO365.
         password (string): Specifies password of the username to access the
             target source.
+        physical_params (PhysicalParams): Contains all params specified by
+            the user while registering a physical entity.
         physical_type (PhysicalTypeEnum): Specifies the entity type such as
             'kPhysicalHost' if the environment is kPhysical.
             overrideDescription: true
+        proxy_host_source_id_list (list of long|int): Specifies the list of
+            the protection source id of the windows physical host which will
+            be used during the protection and recovery of the sites that
+            belong to a office365 domain.
         pure_type (PureTypeEnum): Specifies the entity type such as
             'kStorageArray' if the environment is kPure.
-        re_register (bool): ReRegister is applicable to Physical Environment.
-            By default, the agent running on a physical host will fail the
-            registration, if it is already registered with the cluster. By
-            setting this option to true, agent can be re-registered with the
-            current cluster.
         source_side_dedup_enabled (bool): This controls whether to use source
             side dedup on the source or not. This is only applicable to
             sources which support source side dedup (e.g., Linux physical
@@ -184,18 +207,25 @@ class RegisterProtectionSourceParameters(object):
     _names = {
         "acropolis_type":'acropolisType',
         "agent_endpoint":'agentEndpoint',
+        "allowed_ip_addresses":'allowedIpAddresses',
         "aws_credentials":'awsCredentials',
         "aws_fleet_params":'awsFleetParams',
         "azure_credentials":'azureCredentials',
         "blacklisted_ip_addresses":'blacklistedIpAddresses',
         "cluster_network_info":'clusterNetworkInfo',
+        "connection_id":'connectionId',
+        "denied_ip_addresses":'deniedIpAddresses',
         "endpoint":'endpoint',
+        "encryption_key":'encryptionKey',
         "environment":'environment',
         "exchange_dag_protection_preference":'exchangeDAGProtectionPreference',
         "force_register":'forceRegister',
         "gcp_credentials":'gcpCredentials',
         "host_type":'hostType',
         "hyperv_type":'hyperVType',
+        "is_internal_encrypted":'isInternalEncrypted',
+        "is_proxy_host":'isProxyHost',
+        "isilon_params":'isilonParams',
         "kubernetes_credentials":'kubernetesCredentials',
         "kubernetes_type":'kubernetesType',
         "kvm_type":'kvmType',
@@ -206,9 +236,10 @@ class RegisterProtectionSourceParameters(object):
         "office_365_region":'office365Region',
         "office_365_type":'office365Type',
         "password":'password',
+        "physical_params":'physicalParams',
         "physical_type":'physicalType',
+        "proxy_host_source_id_list":'proxyHostSourceIdList',
         "pure_type":'pureType',
-        "re_register":'reRegister',
         "source_side_dedup_enabled":'sourceSideDedupEnabled',
         "ssl_verification":'sslVerification',
         "subnets":'subnets',
@@ -224,11 +255,15 @@ class RegisterProtectionSourceParameters(object):
     def __init__(self,
                  acropolis_type=None,
                  agent_endpoint=None,
+                 allowed_ip_addresses=None,
                  aws_credentials=None,
                  aws_fleet_params=None,
                  azure_credentials=None,
                  blacklisted_ip_addresses=None,
                  cluster_network_info=None,
+                 connection_id=None,
+                 denied_ip_addresses=None,
+                 encryption_key=None,
                  endpoint=None,
                  environment=None,
                  exchange_dag_protection_preference=None,
@@ -236,6 +271,9 @@ class RegisterProtectionSourceParameters(object):
                  gcp_credentials=None,
                  host_type=None,
                  hyperv_type=None,
+                 is_internal_encrypted=None,
+                 is_proxy_host=None,
+                 isilon_params=None,
                  kubernetes_credentials=None,
                  kubernetes_type=None,
                  kvm_type=None,
@@ -246,9 +284,10 @@ class RegisterProtectionSourceParameters(object):
                  office_365_region=None,
                  office_365_type=None,
                  password=None,
+                 physical_params=None,
                  physical_type=None,
+                 proxy_host_source_id_list=None,
                  pure_type=None,
-                 re_register=None,
                  source_side_dedup_enabled=None,
                  ssl_verification=None,
                  subnets=None,
@@ -264,11 +303,15 @@ class RegisterProtectionSourceParameters(object):
         # Initialize members of the class
         self.acropolis_type = acropolis_type
         self.agent_endpoint = agent_endpoint
+        self.allowed_ip_addresses = allowed_ip_addresses
         self.aws_credentials = aws_credentials
         self.aws_fleet_params = aws_fleet_params
         self.azure_credentials = azure_credentials
         self.blacklisted_ip_addresses = blacklisted_ip_addresses
         self.cluster_network_info = cluster_network_info
+        self.connection_id = connection_id
+        self.denied_ip_addresses = denied_ip_addresses
+        self.encryption_key = encryption_key
         self.endpoint = endpoint
         self.environment = environment
         self.force_register = force_register
@@ -276,6 +319,9 @@ class RegisterProtectionSourceParameters(object):
         self.gcp_credentials = gcp_credentials
         self.host_type = host_type
         self.hyperv_type = hyperv_type
+        self.is_internal_encrypted = is_internal_encrypted
+        self.is_proxy_host = is_proxy_host
+        self.isilon_params = isilon_params
         self.kubernetes_credentials = kubernetes_credentials
         self.kubernetes_type = kubernetes_type
         self.kvm_type = kvm_type
@@ -286,9 +332,10 @@ class RegisterProtectionSourceParameters(object):
         self.office_365_region = office_365_region
         self.office_365_type = office_365_type
         self.password = password
+        self.physical_params = physical_params
         self.physical_type = physical_type
+        self.proxy_host_source_id_list = proxy_host_source_id_list
         self.pure_type = pure_type
-        self.re_register = re_register
         self.source_side_dedup_enabled = source_side_dedup_enabled
         self.ssl_verification = ssl_verification
         self.subnets = subnets
@@ -321,11 +368,15 @@ class RegisterProtectionSourceParameters(object):
         # Extract variables from the dictionary
         acropolis_type = dictionary.get('acropolisType')
         agent_endpoint = dictionary.get('agentEndpoint')
+        allowed_ip_addresses = dictionary.get('allowedIpAddresses')
         aws_credentials = cohesity_management_sdk.models.aws_credentials.AwsCredentials.from_dictionary(dictionary.get('awsCredentials')) if dictionary.get('awsCredentials') else None
         aws_fleet_params = cohesity_management_sdk.models.a_w_s_fleet_params.AwsFleetParams.from_dictionary(dictionary.get('awsFleetParams')) if dictionary.get('awsFleetParams') else None
         azure_credentials = cohesity_management_sdk.models.azure_credentials.AzureCredentials.from_dictionary(dictionary.get('azureCredentials')) if dictionary.get('azureCredentials') else None
         blacklisted_ip_addresses = dictionary.get('blacklistedIpAddresses')
         cluster_network_info = cohesity_management_sdk.models.fleet_network_params.FleetNetworkParams.from_dictionary(dictionary.get('clusterNetworkInfo')) if dictionary.get('clusterNetworkInfo') else None
+        connection_id = dictionary.get('connectionId')
+        denied_ip_addresses = dictionary.get('deniedIpAddresses')
+        encryption_key = dictionary.get('encryptionKey')
         endpoint = dictionary.get('endpoint')
         environment = dictionary.get('environment')
         exchange_dag_protection_preference = cohesity_management_sdk.models.exchange_dag_protection_preference.ExchangeDAGProtectionPreference.from_dictionary(dictionary.get('exchangeDAGProtectionPreference')) if dictionary.get('exchangeDAGProtectionPreference') else None
@@ -333,6 +384,9 @@ class RegisterProtectionSourceParameters(object):
         gcp_credentials = cohesity_management_sdk.models.gcp_credentials.GcpCredentials.from_dictionary(dictionary.get('gcpCredentials')) if dictionary.get('gcpCredentials') else None
         host_type = dictionary.get('hostType')
         hyperv_type = dictionary.get('hyperVType')
+        is_internal_encrypted = dictionary.get('isInternalEncrypted')
+        is_proxy_host = dictionary.get('isProxyHost')
+        isilon_params = cohesity_management_sdk.models.registered_protection_source_isilon_params.RegisteredProtectionSourceIsilonParams.from_dictionary(dictionary.get('isilonParams')) if dictionary.get('isilonParams') else None
         kubernetes_credentials = cohesity_management_sdk.models.kubernetes_credentials.KubernetesCredentials.from_dictionary(dictionary.get('kubernetesCredentials')) if dictionary.get('kubernetesCredentials') else None
         kubernetes_type = dictionary.get('kubernetesType')
         kvm_type = dictionary.get('kvmType')
@@ -347,9 +401,10 @@ class RegisterProtectionSourceParameters(object):
                 office365_credentials_list.append(cohesity_management_sdk.models.office_365_credentials.Office365Credentials.from_dictionary(structure))
         office_365_region = dictionary.get('office365Region')
         password = dictionary.get('password')
+        physical_params = cohesity_management_sdk.models.physical_params.PhysicalParams.from_dictionary(dictionary.get('physicalParams')) if dictionary.get('physicalParams') else None
         physical_type = dictionary.get('physicalType')
+        proxy_host_source_id_list = dictionary.get('proxyHostSourceIdList')
         pure_type = dictionary.get('pureType')
-        re_register = dictionary.get('reRegister')
         source_side_dedup_enabled = dictionary.get('sourceSideDedupEnabled')
         ssl_verification = cohesity_management_sdk.models.ssl_verification.SslVerification.from_dictionary(dictionary.get('sslVerification')) if dictionary.get('sslVerification') else None
         subnets = None
@@ -372,11 +427,15 @@ class RegisterProtectionSourceParameters(object):
         # Return an object of this model
         return cls(acropolis_type,
                    agent_endpoint,
+                   allowed_ip_addresses,
                    aws_credentials,
                    aws_fleet_params,
                    azure_credentials,
                    blacklisted_ip_addresses,
                    cluster_network_info,
+                   connection_id,
+                   denied_ip_addresses,
+                   encryption_key,
                    endpoint,
                    environment,
                    exchange_dag_protection_preference,
@@ -384,6 +443,9 @@ class RegisterProtectionSourceParameters(object):
                    gcp_credentials,
                    host_type,
                    hyperv_type,
+                   is_internal_encrypted,
+                   is_proxy_host,
+                   isilon_params,
                    kubernetes_credentials,
                    kubernetes_type,
                    kvm_type,
@@ -394,9 +456,10 @@ class RegisterProtectionSourceParameters(object):
                    office_365_region,
                    office_365_type,
                    password,
+                   physical_params,
                    physical_type,
+                   proxy_host_source_id_list,
                    pure_type,
-                   re_register,
                    source_side_dedup_enabled,
                    ssl_verification,
                    subnets,
