@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 class ServiceNameServiceGflagsEnum(object):
 
@@ -36,7 +36,6 @@ class ServiceNameServiceGflagsEnum(object):
     'kNexusProxy' is a service that links the Nexus service to other services
     on the Cluster.
     'kStorageProxy' is a service for accessing data on external entities.
-    'kTricorder' is a diagnostic health testing service for Clusters.
     'kRtClient' is a reverse tunneling client service.
     'kVaultProxy' is a service for managing external targets that Clusters
     can be backed up to.
@@ -55,9 +54,9 @@ class ServiceNameServiceGflagsEnum(object):
     'kSmb2Proxy' is a new SMB protocol service.
     'kOs' can be specified in order to do a full reboot.
     'kAtom' is a service for receiving data for the Continuous Data Protection.
-    'kPatch' is a service for downloading and applying patches.
-    'kCompass' is a service for serving dns request for external and internal
-    traffic.
+    'kEtlServer' is a service responsible for ETling data for globalsearch.
+    'kIcebox' is service that links Icebox service to other services on
+    cluster.
 
     Attributes:
         KAPOLLO: TODO: type description here.
@@ -78,7 +77,6 @@ class ServiceNameServiceGflagsEnum(object):
         KNEXUS: TODO: type description here.
         KNEXUSPROXY: TODO: type description here.
         KSTORAGEPROXY: TODO: type description here.
-        KTRICORDER: TODO: type description here.
         KRTCLIENT: TODO: type description here.
         KVAULTPROXY: TODO: type description here.
         KSMBPROXY: TODO: type description here.
@@ -91,8 +89,7 @@ class ServiceNameServiceGflagsEnum(object):
         KSMB2PROXY: TODO: type description here.
         KOS: TODO: type description here.
         KATOM: TODO: type description here.
-        KPATCH: TODO: type description here.
-        KCOMPASS: TODO: type description here.
+        KICEBOX: TODO: type description here.
 
     """
 
@@ -132,8 +129,6 @@ class ServiceNameServiceGflagsEnum(object):
 
     KSTORAGEPROXY = 'kStorageProxy'
 
-    KTRICORDER = 'kTricorder'
-
     KRTCLIENT = 'kRtClient'
 
     KVAULTPROXY = 'kVaultProxy'
@@ -158,6 +153,4 @@ class ServiceNameServiceGflagsEnum(object):
 
     KATOM = 'kAtom'
 
-    KPATCH = 'kPatch'
-
-    KCOMPASS = 'kCompass'
\ No newline at end of file
+    KICEBOX = 'kIcebox'
\ No newline at end of file
