@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 
 class ServiceProcessEntry(object):
@@ -36,8 +36,7 @@ class ServiceProcessEntry(object):
             responsible for creation of Clusters and configuration of Nodes
             and networking. 'kNexusProxy' is a service that links the Nexus
             service to other services on the Cluster. 'kStorageProxy' is a
-            service for accessing data on external entities. 'kTricorder' is a
-            diagnostic health testing service for Clusters. 'kRtClient' is a
+            service for accessing data on external entities. 'kRtClient' is a
             reverse tunneling client service. 'kVaultProxy' is a service for
             managing external targets that Clusters can be backed up to.
             'kSmbProxy' is an SMB protocol service. 'kBridgeProxy' is the
@@ -51,9 +50,10 @@ class ServiceProcessEntry(object):
             service for communicating with the Cohesity proxies for
             multitenancy. 'kSmb2Proxy' is a new SMB protocol service. 'kOs'
             can be specified in order to do a full reboot.
-            'kPatch' is a service for downloading and applying patches.
-            'kCompass' is a service for serving dns request for external and
-            internal traffic.
+            'kEtlServer' is a service responsible for ETling data for
+            globalsearch.
+            'kIcebox' is service that links Icebox service to other services on
+            cluster.
 
     """
 
