@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 
 class UnRegisterApplicationServersParameters(object):
@@ -55,6 +55,8 @@ class UnRegisterApplicationServersParameters(object):
             environment. 'kHdfs' indicates Hdfs Protection Source environment.
             'kHive' indicates Hive Protection Source environment. 'kHBase'
             indicates HBase Protection Source environment.
+            'kUDA' indicates Universal Data Adapter Protection Source
+            environment.
 
     """
 
