@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 import cohesity_management_sdk.models.gflag
 
@@ -10,6 +10,9 @@ class UpdateGflagParameters(object):
     Specifies the parameters for updating service gflags.
 
     Attributes:
+        effective_now (bool): Specifies whether to apply the change
+            immediately. If set to true, the gflag change will work without
+            restarting the service.
         gflags (list of Gflag): Specifies a list of gflags. These will be
             added to the existing flags for the service. The values will be
             overwritten if required. If no value for gflag is specified, this
@@ -40,8 +43,7 @@ class UpdateGflagParameters(object):
             responsible for creation of Clusters and configuration of Nodes
             and networking. 'kNexusProxy' is a service that links the Nexus
             service to other services on the Cluster. 'kStorageProxy' is a
-            service for accessing data on external entities. 'kTricorder' is a
-            diagnostic health testing service for Clusters. 'kRtClient' is a
+            service for accessing data on external entities. 'kRtClient' is a
             reverse tunneling client service. 'kVaultProxy' is a service for
             managing external targets that Clusters can be backed up to.
             'kSmbProxy' is an SMB protocol service. 'kBridgeProxy' is the
@@ -55,23 +57,32 @@ class UpdateGflagParameters(object):
             service for communicating with the Cohesity proxies for
             multitenancy. 'kSmb2Proxy' is a new SMB protocol service. 'kOs'
             can be specified in order to do a full reboot.
+            'kAtom' is a service for receiving data for the Continuous Data
+            Protection.
+            'kEtlServer' is a service responsible for ETling data for
+            globalsearch.
+            'kIcebox' is service that links Icebox service to other services on
+            cluster.
 
     """
 
     # Create a mapping from Model property names to API property names
     _names = {
+        "effective_now":'effectiveNow',
         "service_name":'serviceName',
         "reason":'reason',
         "gflags":'gflags'
     }
 
     def __init__(self,
+                 effective_now=None,
                  gflags=None,
                  reason=None,
                  service_name=None):
         """Constructor for the UpdateGflagParameters class"""
 
         # Initialize members of the class
+        self.effective_now = effective_now
         self.gflags = gflags
         self.reason = reason
         self.service_name = service_name
@@ -95,6 +106,7 @@ class UpdateGflagParameters(object):
             return None
 
         # Extract variables from the dictionary
+        effective_now = dictionary.get('effectiveNow')
         service_name = dictionary.get('serviceName')
         reason = dictionary.get('reason')
         gflags = None
@@ -104,6 +116,6 @@ class UpdateGflagParameters(object):
                 gflags.append(cohesity_management_sdk.models.gflag.Gflag.from_dictionary(structure))
 
         # Return an object of this model
-        return cls(gflags, reason, service_name)
+        return cls(effective_now, gflags, reason, service_name)
 
 
