@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 import cohesity_management_sdk.models.aws_credentials
 import cohesity_management_sdk.models.a_w_s_fleet_params
@@ -27,6 +27,9 @@ class UpdateProtectionSourceParameters(object):
     Attributes:
         agent_endpoint (string): Specifies the agent endpoint if it is
             different from the source endpoint.
+        allowed_ip_addresses (list of string): Specifies the list of IP
+            Addresses on the registered source to be exclusively allowed for
+            doing any type of IO operations.
         aws_credentials (AwsCredentials): Specifies the credentials to
             authenticate with AWS Cloud Platform.
         aws_fleet_params (AwsFleetParams): Specifies information related to
@@ -40,6 +43,13 @@ class UpdateProtectionSourceParameters(object):
         cluster_network_info (FleetNetworkParams): Specifies information
             related to cluster. This is only valid for CE clusters. This is
             only populated for kIAMUser entity.
+        connection_id (long|int): Specifies the Bifrost realm to be
+            associated with the source root. Whenever needed, the workflows
+            related to this source would then only use Bifrosts from the
+            specified realm.
+        denied_ip_addresses (list of string): Specifies the list of IP
+            Addresses on the registered source to be denied for doing any
+            type of IO operations.
         endpoint (string): Specifies the network endpoint of the Protection
             Source where it is reachable. It could be an URL or hostname or an
             IP address of the Protection Source.
@@ -63,6 +73,10 @@ class UpdateProtectionSourceParameters(object):
             'kSolaris' indicates the Oracle Solaris operating system.
             'kSapHana' indicates the Sap Hana database system developed by SAP
             SE. 'kOther' indicates the other types of operating system.
+        is_proxy_host (bool): Specifies if the physical host has to be
+            registered as a proxy host.
+        isilon_params (RegisteredProtectionSourceIsilonParams): Specifies the
+            registered protection source params for Isilon Source
         kubernetes_credentials (KubernetesCredentials): Specifies the
             credentials to authenticate with a Kubernetes Cluster.
         minimum_free_space_gb (long|int): Specifies the minimum space in GB
@@ -75,11 +89,10 @@ class UpdateProtectionSourceParameters(object):
         office_365_region (string): Specifies the region for Office365.
         password (string): Specifies password of the username to access the
             target source.
-        re_register (bool): ReRegister is applicable to Physical Environment.
-            By default, the agent running on a physical host will fail the
-            registration, if it is already registered with the cluster. By
-            setting this option to true, agent can be re-registered with the
-            current cluster.
+        proxy_host_source_id_list (list of long|int): Specifies the list of
+            the protection source id of the windows physical host which will
+            be used during the protection and recovery of the sites that
+            belong to a office365 domain.
         source_side_dedup_enabled (bool): This controls whether to use source
             side dedup on the source or not. This is only applicable to
             sources which support source side dedup (e.g., Linux physical
@@ -111,23 +124,28 @@ class UpdateProtectionSourceParameters(object):
     # Create a mapping from Model property names to API property names
     _names = {
         "agent_endpoint":'agentEndpoint',
+        "allowed_ip_addresses":'allowedIpAddresses',
         "aws_credentials":'awsCredentials',
         "aws_fleet_params":'awsFleetParams',
         "azure_credentials":'azureCredentials',
         "blacklisted_ip_addresses":'blacklistedIpAddresses',
         "cluster_network_info":'clusterNetworkInfo',
+        "connection_id":'connectionId',
+        "denied_ip_addresses":'deniedIpAddresses',
         "endpoint":'endpoint',
         "exchange_dag_protection_preference":'exchangeDagProtectionPreference',
         "force_register":'forceRegister',
         "gcp_credentials":'gcpCredentials',
         "host_type":'hostType',
+        "is_proxy_host":'isProxyHost',
+        "isilon_params":'isilonParams',
         "kubernetes_credentials":'kubernetesCredentials',
         "minimum_free_space_gb":'minimumFreeSpaceGB',
         "nas_mount_credentials":'nasMountCredentials',
         "office_365_credentials":'office365Credentials',
         "office_365_region":'office365Region',
         "password":'password',
-        "re_register":'reRegister',
+        "proxy_host_source_id_list":'proxyHostSourceIdList',
         "source_side_dedup_enabled":'sourceSideDedupEnabled',
         "ssl_verification":'sslVerification',
         "subnets":'subnets',
@@ -140,15 +158,20 @@ class UpdateProtectionSourceParameters(object):
 
     def __init__(self,
                  agent_endpoint=None,
+                 allowed_ip_addresses=None,
                  aws_credentials=None,
                  aws_fleet_params=None,
                  azure_credentials=None,
                  blacklisted_ip_addresses=None,
                  cluster_network_info=None,
+                 connection_id=None,
+                 denied_ip_addresses=None,
                  endpoint=None,
                  exchange_dag_protection_preference=None,
                  force_register=None,
                  gcp_credentials=None,
+                 is_proxy_host=None,
+                 isilon_params=None,
                  host_type=None,
                  kubernetes_credentials=None,
                  minimum_free_space_gb=None,
@@ -156,7 +179,7 @@ class UpdateProtectionSourceParameters(object):
                  office_365_credentials=None,
                  office_365_region=None,
                  password=None,
-                 re_register=None,
+                 proxy_host_source_id_list=None,
                  source_side_dedup_enabled=None,
                  ssl_verification=None,
                  subnets=None,
@@ -169,15 +192,20 @@ class UpdateProtectionSourceParameters(object):
 
         # Initialize members of the class
         self.agent_endpoint = agent_endpoint
+        self.allowed_ip_addresses = allowed_ip_addresses
         self.aws_credentials = aws_credentials
         self.aws_fleet_params = aws_fleet_params
         self.azure_credentials = azure_credentials
         self.blacklisted_ip_addresses = blacklisted_ip_addresses
         self.cluster_network_info = cluster_network_info
+        self.connection_id = connection_id
+        self.denied_ip_addresses = denied_ip_addresses
         self.endpoint = endpoint
         self.exchange_dag_protection_preference = exchange_dag_protection_preference
         self.force_register = force_register
         self.gcp_credentials = gcp_credentials
+        self.is_proxy_host = is_proxy_host
+        self.isilon_params = isilon_params
         self.host_type = host_type
         self.kubernetes_credentials = kubernetes_credentials
         self.minimum_free_space_gb = minimum_free_space_gb
@@ -185,7 +213,7 @@ class UpdateProtectionSourceParameters(object):
         self.office_365_credentials = office_365_credentials
         self.office_365_region = office_365_region
         self.password = password
-        self.re_register = re_register
+        self.proxy_host_source_id_list = proxy_host_source_id_list
         self.source_side_dedup_enabled = source_side_dedup_enabled
         self.ssl_verification = ssl_verification
         self.subnets = subnets
@@ -215,23 +243,28 @@ class UpdateProtectionSourceParameters(object):
 
         # Extract variables from the dictionary
         agent_endpoint = dictionary.get('agentEndpoint')
+        allowed_ip_addresses = dictionary.get('allowedIpAddresses')
         aws_credentials = cohesity_management_sdk.models.aws_credentials.AwsCredentials.from_dictionary(dictionary.get('awsCredentials')) if dictionary.get('awsCredentials') else None
         aws_fleet_params = cohesity_management_sdk.models.a_w_s_fleet_params.AwsFleetParams.from_dictionary(dictionary.get('awsFleetParams')) if dictionary.get('awsFleetParams') else None
         azure_credentials = cohesity_management_sdk.models.azure_credentials.AzureCredentials.from_dictionary(dictionary.get('azureCredentials')) if dictionary.get('azureCredentials') else None
         blacklisted_ip_addresses = dictionary.get('blacklistedIpAddresses')
         cluster_network_info = cohesity_management_sdk.models.fleet_network_params.FleetNetworkParams.from_dictionary(dictionary.get('clusterNetworkInfo')) if dictionary.get('clusterNetworkInfo') else None
+        connection_id = dictionary.get('connectionId')
+        denied_ip_addresses = dictionary.get('deniedIpAddresses')
         exchange_dag_protection_preference = cohesity_management_sdk.models.exchange_dag_protection_preference.ExchangeDAGProtectionPreference.from_dictionary(dictionary.get('exchangeDagProtectionPreference')) if dictionary.get('exchangeDagProtectionPreference') else None
         endpoint = dictionary.get('endpoint')
         force_register = dictionary.get('forceRegister')
         gcp_credentials = cohesity_management_sdk.models.gcp_credentials.GcpCredentials.from_dictionary(dictionary.get('gcpCredentials')) if dictionary.get('gcpCredentials') else None
         host_type = dictionary.get('hostType')
+        is_proxy_host = dictionary.get('isProxyHost')
+        isilon_params = cohesity_management_sdk.models.registered_protection_source_isilon_params.RegisteredProtectionSourceIsilonParams.from_dictionary(dictionary.get('isilonParams')) if dictionary.get('isilonParams') else None
         kubernetes_credentials = cohesity_management_sdk.models.kubernetes_credentials.KubernetesCredentials.from_dictionary(dictionary.get('kubernetesCredentials')) if dictionary.get('kubernetesCredentials') else None
         minimum_free_space_gb = dictionary.get('minimumFreeSpaceGB')
         nas_mount_credentials = cohesity_management_sdk.models.nas_mount_credential_params.NasMountCredentialParams.from_dictionary(dictionary.get('nasMountCredentials')) if dictionary.get('nasMountCredentials') else None
         office_365_credentials = cohesity_management_sdk.models.office_365_credentials.Office365Credentials.from_dictionary(dictionary.get('office365Credentials')) if dictionary.get('office365Credentials') else None
         office_365_region = dictionary.get('office365Region')
         password = dictionary.get('password')
-        re_register = dictionary.get('reRegister')
+        proxy_host_source_id_list = dictionary.get('proxyHostSourceIdList')
         source_side_dedup_enabled = dictionary.get('sourceSideDedupEnabled')
         ssl_verification = cohesity_management_sdk.models.ssl_verification.SslVerification.from_dictionary(dictionary.get('sslVerification')) if dictionary.get('sslVerification') else None
         subnets = None
@@ -251,23 +284,28 @@ class UpdateProtectionSourceParameters(object):
 
         # Return an object of this model
         return cls(agent_endpoint,
+                   allowed_ip_addresses,
                    aws_credentials,
                    aws_fleet_params,
                    azure_credentials,
                    blacklisted_ip_addresses,
                    cluster_network_info,
+                   connection_id,
+                   denied_ip_addresses,
                    endpoint,
                    exchange_dag_protection_preference,
                    force_register,
                    gcp_credentials,
                    host_type,
+                   is_proxy_host,
+                   isilon_params,
                    kubernetes_credentials,
                    minimum_free_space_gb,
                    nas_mount_credentials,
                    office_365_credentials,
                    office_365_region,
                    password,
-                   re_register,
+                   proxy_host_source_id_list,
                    source_side_dedup_enabled,
                    ssl_verification,
                    subnets,
