@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 import cohesity_management_sdk.models.view_alias
 import cohesity_management_sdk.models.antivirus_scan_config
@@ -96,6 +96,8 @@ class View(object):
             is for externally triggered backup target.
             will no longer be able to write to this view if this is set to
             true.
+        is_read_only (bool): Specifies if the view is a read only view. User
+            will no longer be able to write to this view if this is set to true.
         is_target_for_migrated_data (bool): Specifies if a view contains
             migrated data.
         logical_quota (QuotaPolicy): Specifies an optional logical quota limit
@@ -207,6 +209,7 @@ class View(object):
         "file_extension_filter":'fileExtensionFilter',
         "file_lock_config":'fileLockConfig',
         "is_externally_triggered_backup_target":'isExternallyTriggeredBackupTarget',
+        "is_read_only":'isReadOnly',
         "is_target_for_migrated_data":'isTargetForMigratedData',
         "logical_quota":'logicalQuota',
         "logical_usage_bytes":'logicalUsageBytes',
@@ -266,6 +269,7 @@ class View(object):
                  file_extension_filter=None,
                  file_lock_config=None,
                  is_externally_triggered_backup_target=None,
+                 is_read_only=None,
                  is_target_for_migrated_data=None,
                  logical_quota=None,
                  logical_usage_bytes=None,
@@ -325,6 +329,7 @@ class View(object):
         self.file_extension_filter = file_extension_filter
         self.file_lock_config = file_lock_config
         self.is_externally_triggered_backup_target = is_externally_triggered_backup_target
+        self.is_read_only = is_read_only
         self.is_target_for_migrated_data = is_target_for_migrated_data
         self.logical_quota = logical_quota
         self.logical_usage_bytes = logical_usage_bytes
@@ -405,6 +410,7 @@ class View(object):
         file_extension_filter = cohesity_management_sdk.models.file_extension_filter.FileExtensionFilter.from_dictionary(dictionary.get('fileExtensionFilter')) if dictionary.get('fileExtensionFilter') else None
         file_lock_config = cohesity_management_sdk.models.file_level_data_lock_config.FileLevelDataLockConfig.from_dictionary(dictionary.get('fileLockConfig')) if dictionary.get('fileLockConfig') else None
         is_externally_triggered_backup_target = dictionary.get('isExternallyTriggeredBackupTarget')
+        is_read_only = dictionary.get('isReadOnly')
         is_target_for_migrated_data = dictionary.get('isTargetForMigratedData')
         logical_quota = cohesity_management_sdk.models.quota_policy.QuotaPolicy.from_dictionary(dictionary.get('logicalQuota')) if dictionary.get('logicalQuota') else None
         logical_usage_bytes = dictionary.get('logicalUsageBytes')
@@ -475,6 +481,7 @@ class View(object):
                    file_extension_filter,
                    file_lock_config,
                    is_externally_triggered_backup_target,
+                   is_read_only,
                    is_target_for_migrated_data,
                    logical_quota,
                    logical_usage_bytes,
