@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Cohesity Inc.
+# Copyright 2022 Cohesity Inc.
 
 import cohesity_management_sdk.models.smb_permission
 import cohesity_management_sdk.models.subnet
@@ -12,6 +12,8 @@ class ViewAlias(object):
 
     Attributes:
         alias_name (string): Alias name.
+        enable_filer_audit_log (bool): Specifies whether to enable filer
+            audit log on this view alias.
         enable_smb_encryption (bool): Specifies the SMB encryption for the
             View Alias. If set, it enables the SMB encryption for the View
             Alias. Encryption is supported only by SMB 3.x dialects. Dialects
@@ -29,6 +31,8 @@ class ViewAlias(object):
             addresses that have permissions to access the View Alias.
             (Overrides the Subnets specified at the global Cohesity Cluster
             level and View level.)
+        super_user_sids (list of string): Specifies a list of user sids who
+            have Superuser access to this view.
         view_name (string): View name.
         view_path (string): View path for the alias.
 
@@ -37,33 +41,39 @@ class ViewAlias(object):
     # Create a mapping from Model property names to API property names
     _names = {
         "alias_name":'aliasName',
+        "enable_filer_audit_log":'enableFilerAuditLog',
         "enable_smb_encryption":'enableSmbEncryption',
         "enable_smb_view_discovery":'enableSmbViewDiscovery',
         "enforce_smb_encryption":'enforceSmbEncryption',
         "share_permissions":'sharePermissions',
         "subnet_whitelist":'subnetWhitelist',
+        "super_user_sids":'superUserSids',
         "view_name":'viewName',
         "view_path":'viewPath'
     }
 
     def __init__(self,
                  alias_name=None,
+                 enable_filer_audit_log=None,
                  enable_smb_encryption=None,
                  enable_smb_view_discovery=None,
                  enforce_smb_encryption=None,
                  share_permissions=None,
                  subnet_whitelist=None,
+                 super_user_sids=None,
                  view_name=None,
                  view_path=None):
         """Constructor for the ViewAlias class"""
 
         # Initialize members of the class
         self.alias_name = alias_name
+        self.enable_filer_audit_log = enable_filer_audit_log
         self.enable_smb_encryption = enable_smb_encryption
         self.enable_smb_view_discovery = enable_smb_view_discovery
         self.enforce_smb_encryption = enforce_smb_encryption
         self.share_permissions = share_permissions
         self.subnet_whitelist = subnet_whitelist
+        self.super_user_sids = super_user_sids
         self.view_name = view_name
         self.view_path = view_path
 
@@ -87,6 +97,7 @@ class ViewAlias(object):
 
         # Extract variables from the dictionary
         alias_name = dictionary.get('aliasName')
+        enable_filer_audit_log = dictionary.get('enableFilerAuditLog')
         enable_smb_encryption = dictionary.get('enableSmbEncryption')
         enable_smb_view_discovery = dictionary.get('enableSmbViewDiscovery')
         enforce_smb_encryption = dictionary.get('enforceSmbEncryption')
@@ -100,16 +111,19 @@ class ViewAlias(object):
             subnet_whitelist = list()
             for structure in dictionary.get('subnetWhitelist'):
                 subnet_whitelist.append(cohesity_management_sdk.models.subnet.Subnet.from_dictionary(structure))
+        super_user_sids = dictionary.get('superUserSids')
         view_name = dictionary.get('viewName')
         view_path = dictionary.get('viewPath')
 
         # Return an object of this model
         return cls(alias_name,
+                   enable_filer_audit_log,
                    enable_smb_encryption,
                    enable_smb_view_discovery,
                    enforce_smb_encryption,
                    share_permissions,
                    subnet_whitelist,
+                   super_user_sids,
                    view_name,
                    view_path)
 
