@@ -11,20 +11,24 @@ class CommonSourceRegistrationRequestParams(object):
     Attributes:
         environment (Environment8Enum): Specifies the environment type of the
             Protection Source.
+        name (string): A user specified name for this source.
 
     """
 
     # Create a mapping from Model property names to API property names
     _names = {
-        "environment":'environment'
+        "environment":'environment',
+        "name": 'name'
     }
 
     def __init__(self,
-                 environment=None):
+                 environment=None,
+                 name=None):
         """Constructor for the CommonSourceRegistrationRequestParams class"""
 
         # Initialize members of the class
         self.environment = environment
+        self.name = name
 
 
     @classmethod
@@ -46,8 +50,9 @@ class CommonSourceRegistrationRequestParams(object):
 
         # Extract variables from the dictionary
         environment = dictionary.get('environment')
+        name = dictionary.get('name')
 
         # Return an object of this model
-        return cls(environment)
+        return cls(environment, name)
 
 
