@@ -90,6 +90,10 @@ class UpdateViewParam(object):
         view_lock_enabled (bool): Specifies whether view lock is enabled. If
             enabled the view cannot be modified or deleted until unlock. By
             default it is disabled.
+        is_externally_triggered_backup_target (bool): Specifies whether the
+            view is for externally triggered backup target. If so, Magneto
+            will ignore the backup schedule for the view protection job of
+            this view. By default it is disabled.
         enable_nfs_view_discovery (bool): If set, it enables discovery of view
             for NFS.
         nfs_all_squash
@@ -156,6 +160,7 @@ class UpdateViewParam(object):
         "swift_project_name":'swiftProjectName',
         "access_sids":'accessSids',
         "view_lock_enabled":'viewLockEnabled',
+        "is_externally_triggered_backup_target":'isExternallyTriggeredBackupTarget',
         "enable_nfs_view_discovery":'enableNfsViewDiscovery',
         "nfs_all_squash":'nfsAllSquash',
         "nfs_root_permissions":'nfsRootPermissions',
@@ -196,6 +201,7 @@ class UpdateViewParam(object):
                  swift_project_name=None,
                  access_sids=None,
                  view_lock_enabled=None,
+                 is_externally_triggered_backup_target=None,
                  enable_nfs_view_discovery=None,
                  nfs_all_squash=None,
                  nfs_root_permissions=None,
@@ -236,6 +242,7 @@ class UpdateViewParam(object):
         self.swift_project_name = swift_project_name
         self.access_sids = access_sids
         self.view_lock_enabled = view_lock_enabled
+        self.is_externally_triggered_backup_target = is_externally_triggered_backup_target
         self.enable_nfs_view_discovery = enable_nfs_view_discovery
         self.nfs_all_squash = nfs_all_squash
         self.nfs_root_permissions = nfs_root_permissions
@@ -301,6 +308,7 @@ class UpdateViewParam(object):
         swift_project_name = dictionary.get('swiftProjectName')
         access_sids = dictionary.get('accessSids')
         view_lock_enabled = dictionary.get('viewLockEnabled')
+        is_externally_triggered_backup_target = dictionary.get('isExternallyTriggeredBackupTarget')
         enable_nfs_view_discovery = dictionary.get('enableNfsViewDiscovery')
         nfs_all_squash = cohesity_management_sdk.models_v2.nfs_squash_specifies_the_squash_config_for_client_subnet_whitelist.NfsSquashSpecifiesTheSquashConfigForClientSubnetWhitelist.from_dictionary(dictionary.get('nfsAllSquash')) if dictionary.get('nfsAllSquash') else None
         nfs_root_permissions = cohesity_management_sdk.models_v2.nfs_root_permissions.NfsRootPermissions.from_dictionary(dictionary.get('nfsRootPermissions')) if dictionary.get('nfsRootPermissions') else None
@@ -344,6 +352,7 @@ class UpdateViewParam(object):
                    swift_project_name,
                    access_sids,
                    view_lock_enabled,
+                   is_externally_triggered_backup_target,
                    enable_nfs_view_discovery,
                    nfs_all_squash,
                    nfs_root_permissions,
